package java.beans;

import java.util.Locale;
import java.util.HashMap;
import java.util.IdentityHashMap;
import java.util.Map;

class NameGenerator
{
    private Map<Object, String> valueToName;
    private Map<String, Integer> nameToCount;
    
    public NameGenerator() {
        this.valueToName = new IdentityHashMap();
        this.nameToCount = new HashMap();
    }
    
    public void clear() {
        this.valueToName.clear();
        this.nameToCount.clear();
    }
    
    public static String unqualifiedClassName(Class clazz) {
        if (clazz.isArray()) {
            return unqualifiedClassName(clazz.getComponentType()) + "Array";
        }
        String name = clazz.getName();
        return name.substring(name.lastIndexOf(46) + 1);
    }
    
    public static String capitalize(String s) {
        if (s == null || s.length() == 0) {
            return s;
        }
        return s.substring(0, 1).toUpperCase(Locale.ENGLISH) + s.substring(1);
    }
    
    public String instanceName(Object o) {
        if (o == null) {
            return "null";
        }
        if ((o instanceof Class)) {
            return unqualifiedClassName((Class)o);
        }
        String s = (String)this.valueToName.get(o);
        if (s != null) {
            return s;
        }
        String unqualifiedClassName = unqualifiedClassName(o.getClass());
        Integer n = (Integer)this.nameToCount.get(unqualifiedClassName);
        int n2 = (n == null) ? 0 : ((int)n + 1);
        this.nameToCount.put(unqualifiedClassName, new Integer(n2));
        String string = unqualifiedClassName + n2;
        this.valueToName.put(o, string);
        return string;
    }
}
